.. moexalgo documentation master file, created by
   sphinx-quickstart on Wed Aug  9 15:14:33 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to MOEXalgo's documentation!
==================================================

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
